<div id="need-help">
  <h3>Need help?</h3>
  Try <a href="https://gitter.im/python-trio/general">chat</a> or <a
  href="https://stackoverflow.com/questions/ask?tags=python+{{ project }}">StackOverflow</a>.
</div>